@@ -16,8 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: slowcat.c,v 1.4 2004/04/27 20:48:17 nalin Exp $"
-#include "../config.h"
+#include <config.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <errno.h>
@@ -98,7 +97,7 @@ main(int argc, char **argv)
 			}
 			break;
 		default:
-			fprintf(stderr, "Usage: slowcat [-t delay] [-c chunksize] [file ...]\n");
+			g_printerr("Usage: slowcat [-t delay] [-c chunksize] [file ...]\n");
 			exit(1);
 			break;
 		}
