@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "../config.h"
+#include <config.h>
 #include <stdio.h>
 #include <string.h>
 #include <gtk/gtk.h>
@@ -619,9 +619,13 @@ vte_bg_get_pixmap(VteBg *bg,
 		}
 		break;
 	case VTE_BG_SOURCE_PIXBUF:
-		pixbuf = source_pixbuf;
-		if (GDK_IS_PIXBUF(pixbuf)) {
-			g_object_ref(pixbuf);
+		if (GDK_IS_PIXBUF(source_pixbuf)) {
+                        /* If we're going to modify the pixbuf below, make a copy first! */
+                        if (saturation != 1.0) {
+                                pixbuf = gdk_pixbuf_copy(source_pixbuf);
+                        } else {
+                                pixbuf = g_object_ref(source_pixbuf);
+                        }
 		}
 		break;
 	case VTE_BG_SOURCE_FILE:
@@ -671,109 +675,3 @@ vte_bg_get_pixmap(VteBg *bg,
 
 	return item->pixmap;
 }
-
-GdkPixbuf *
-vte_bg_get_pixbuf(VteBg *bg,
-		  enum VteBgSourceType source_type,
-		  GdkPixbuf *source_pixbuf,
-		  const char *source_file,
-		  const GdkColor *tint,
-		  double saturation)
-{
-	struct VteBgCacheItem *item;
-	gpointer cached;
-	GdkPixbuf *pixbuf;
-	GdkColormap *rcolormap;
-	char *file;
-
-	if (source_type == VTE_BG_SOURCE_NONE) {
-		return NULL;
-	}
-
-	cached = vte_bg_cache_search(bg, source_type,
-				     source_pixbuf, source_file,
-				     tint, saturation, NULL, TRUE, FALSE);
-	if (cached != NULL) {
-		return cached;
-	}
-
-	item = g_slice_new(struct VteBgCacheItem);
-	item->source_type = source_type;
-	item->source_pixbuf = NULL;
-	item->source_file = NULL;
-	item->tint_color = *tint;
-	item->saturation = saturation;
-	item->pixmap = NULL;
-	item->pixbuf = NULL;
-	pixbuf = NULL;
-	file = NULL;
-
-	switch (source_type) {
-	case VTE_BG_SOURCE_ROOT:
-		if (GDK_IS_PIXMAP(bg->root_pixmap)) {
-			gint width, height;
-
-			/* If the pixmap doesn't have a colormap, tell GTK+ that
-			 * it shares the root window's colormap. */
-			rcolormap = gdk_drawable_get_colormap(gdk_screen_get_root_window(bg->screen));
-			if (gdk_drawable_get_colormap(bg->root_pixmap) == NULL) {
-				gdk_drawable_set_colormap(bg->root_pixmap, rcolormap);
-			}
-
-			/* Read the pixmap's size. */
-			gdk_error_trap_push();
-			width = height = -1;
-			gdk_drawable_get_size(bg->root_pixmap, &width, &height);
-			_vte_bg_display_sync(bg);
-			gdk_error_trap_pop();
-
-			/* If we got a valid size, read the pixmap's
-			 * contents. */
-			if ((width > 0) && (height > 0)) {
-				gdk_error_trap_push();
-				pixbuf = gdk_pixbuf_get_from_drawable(NULL,
-								      bg->root_pixmap,
-								      NULL,
-								      0, 0,
-								      0, 0,
-								      width, height);
-				_vte_bg_display_sync(bg);
-				gdk_error_trap_pop();
-			}
-		}
-		break;
-	case VTE_BG_SOURCE_PIXBUF:
-		pixbuf = source_pixbuf;
-		if (G_IS_OBJECT(pixbuf)) {
-			g_object_ref(pixbuf);
-		}
-		break;
-	case VTE_BG_SOURCE_FILE:
-		if ((source_file != NULL) && (strlen(source_file) > 0)) {
-			file = g_strdup(source_file);
-			pixbuf = gdk_pixbuf_new_from_file(source_file, NULL);
-		}
-		break;
-	default:
-		g_assert_not_reached();
-		break;
-	}
-
-	item->source_pixbuf = pixbuf;
-	item->source_file = file;
-
-	if (GDK_IS_PIXBUF(item->source_pixbuf)) {
-		if (saturation == 1.0) {
-			g_object_ref(item->source_pixbuf);
-			item->pixbuf = item->source_pixbuf;
-		} else {
-			item->pixbuf = gdk_pixbuf_copy(item->source_pixbuf);
-			vte_bg_desaturate_pixbuf(item->pixbuf,
-						 tint, saturation);
-		}
-	}
-
-	vte_bg_cache_add(bg, item);
-
-	return item->pixbuf;
-}
